@@ -9,7 +9,7 @@ from heapq import heappop
 
 def apply(loop=None):
     """Patch asyncio to make its event loop reentrant."""
-    loop = loop or events._get_running_loop()
+    loop = loop or asyncio.get_event_loop()
     if not isinstance(loop, asyncio.BaseEventLoop):
         raise ValueError('Can\'t patch loop of type %s' % type(loop))
     if getattr(loop, '_nest_patched', None):
